@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                                 *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -58,7 +57,7 @@ bool DataBase::checkDb(){
     QTextStream QErr(stderr);
 
     QStringList tables;
-    tables << "prefix" << "dir" << "icon" << "images" << "last_run_icon" << "logging" << "providers" << "sysconfig";
+    tables << "prefix" << "dir" << "icon" << "images" << "last_run_icon" << "logging" << "providers" << "sysconfig" << "versions";
 
     QSqlDatabase db = QSqlDatabase::database();
 
@@ -149,6 +148,27 @@ bool DataBase::checkDb(){
                 query.bindValue(":desc", "%REFRESH_WINETRICKS_DESC%");
                 if (!query.exec())
                     return false;
+            } else if (table == "versions"){
+                if(!query.exec("CREATE TABLE versions (wine_dllpath32 TEXT, wine_dllpath64 TEXT, wine_loader TEXT, wine_server TEXT, wine_exec TEXT, id INTEGER PRIMARY KEY, name TEXT);"))
+                    return false;
+
+                // Creating default version reccord
+                Version vers;
+                vers.name_ = "Default";
+
+                // Use previous data is any
+                QSettings settings(APP_SHORT_NAME, "default");
+                if (settings.value("configure", "no") == "yes"){
+                    settings.beginGroup("wine");
+                    vers.wine_exec_ = settings.value("WineBin", QString()).toString();
+                    vers.wine_server_ = settings.value("ServerBin", QString()).toString();
+                    vers.wine_loader_ = settings.value("LoaderBin", QString()).toString();
+                    vers.wine_dllpath32_ = settings.value("WineLibs32", QString()).toString();
+                    vers.wine_dllpath64_ = settings.value("WineLibs64", QString()).toString();
+                    settings.endGroup();
+                }
+                if (!vers.save())
+                    return false;
             }
         }
     }
@@ -206,5 +226,15 @@ bool DataBase::fixup(){
             return false;
         }
     }
+    if (!query.exec("SELECT version_id FROM prefix")){
+        if (!query.exec("ALTER TABLE prefix ADD COLUMN version_id INTEGER")){
+            qDebug()<<"[EE] Cannot alter prefix table";
+            return false;
+        }
+        if (!query.exec("UPDATE prefix SET version_id=1")){
+            qDebug()<<"[EE] Cannot update prefix table";
+            return false;
+        }
+    }
     return true;
 }
