@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                                 *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -36,8 +35,10 @@
 #include <QDebug>
 #include <QDir>
 #include <QObject>
+#include <QSettings>
 
 #include "config.h"
+#include "core/database/versions.h"
 
 /*!
  * \class DataBase
