@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                           *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -131,7 +130,7 @@ QHash<QString,QString> Prefix::getByName(const QString prefix_name) const{
     QSettings settings(APP_SHORT_NAME, "default");
     settings.beginGroup("wine");
 
-    query.prepare("SELECT path, wine_dllpath, wine_loader, wine_server, wine_exec, cdrom_mount, id, name, arch, mountpoint_windrive, run_string FROM prefix WHERE name=:prefix_name");
+    query.prepare("SELECT path, wine_dllpath, wine_loader, wine_server, wine_exec, cdrom_mount, id, name, arch, mountpoint_windrive, run_string, version_id FROM prefix WHERE name=:prefix_name");
     query.bindValue(":prefix_name", prefix_name);
 
     if (query.exec()){
@@ -146,36 +145,10 @@ QHash<QString,QString> Prefix::getByName(const QString prefix_name) const{
                     values.insert("path", query.value(0).toString());
                 }
             }
-            if (!query.value(1).toString().isEmpty()){
-                values.insert("libs", query.value(1).toString());
-            } else {
-                if (query.value(8).toString() == "win32") {
-                    values.insert("libs", settings.value("WineLibs32", "").toString());
-                } else if (query.value(8).toString() == "win64") {
-                    values.insert("libs", settings.value("WineLibs64", "").toString());
-                } else {
-                    if (settings.value("WineLibs64", "").toString().isEmpty()){
-                        values.insert("libs", settings.value("WineLibs32", "").toString());
-                    } else {
-                        values.insert("libs", settings.value("WineLibs64", "").toString());
-                    }
-                }
-            }
-            if (!query.value(2).toString().isEmpty()){
-                values.insert("loader", query.value(2).toString());
-            } else {
-                values.insert("loader", settings.value("LoaderBin", "").toString());
-            }
-            if (!query.value(3).toString().isEmpty()){
-                values.insert("server", query.value(3).toString());
-            } else {
-                values.insert("server", settings.value("ServerBin", "").toString());
-            }
-            if (!query.value(4).toString().isEmpty()){
-                values.insert("bin", query.value(4).toString());
-            } else {
-                values.insert("bin", settings.value("WineBin", "").toString());
-            }
+            values.insert("libs", query.value(1).toString());
+            values.insert("loader", query.value(2).toString());
+            values.insert("server", query.value(3).toString());
+            values.insert("bin", query.value(4).toString());
             values.insert("mount", query.value(5).toString());
             values.insert("id", query.value(6).toString());
             values.insert("name", query.value(7).toString());
@@ -184,8 +157,9 @@ QHash<QString,QString> Prefix::getByName(const QString prefix_name) const{
             if (!query.value(10).toString().isEmpty()){
                 values.insert("run_string", query.value(10).toString());
             } else {
-                values.insert("run_string", RUN_STRING_TEMPLATE);
+                values.insert("run_string", RUN_STRING_TEMPLATE_DEFAULT);
             }
+            values.insert("version_id", query.value(11).toString());
         }
     } else {
         qDebug()<<"SqlError: "<<query.lastError();
@@ -273,9 +247,9 @@ bool Prefix::delByName(const QString prefix_name) const{
     return true;
 }
 
-bool Prefix::addPrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString arch, const QString mountpoint_windrive, const QString run_string) const{
+bool Prefix::addPrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString arch, const QString mountpoint_windrive, const QString run_string, const QString version_id) const{
     QSqlQuery query;
-        query.prepare("INSERT INTO prefix(name, path, wine_exec, wine_server, wine_loader, wine_dllpath, cdrom_mount, arch, mountpoint_windrive, run_string) VALUES(:prefix_name, :prefix_path, :wine_exec, :wine_server, :wine_loader, :wine_dllpath, :cdrom_mount, :arch, :mountpoint_windrive, :run_string);");
+        query.prepare("INSERT INTO prefix(name, path, wine_exec, wine_server, wine_loader, wine_dllpath, cdrom_mount, arch, mountpoint_windrive, run_string, version_id) VALUES(:prefix_name, :prefix_path, :wine_exec, :wine_server, :wine_loader, :wine_dllpath, :cdrom_mount, :arch, :mountpoint_windrive, :run_string, :version_id);");
 
     query.bindValue(":prefix_name", prefix_name);
 
@@ -333,6 +307,12 @@ bool Prefix::addPrefix(const QString prefix_name, const QString prefix_path, con
         query.bindValue(":run_string", run_string);
     }
 
+    if (version_id.isEmpty()){
+        query.bindValue(":version_id", QVariant(QVariant::String));
+    } else {
+        query.bindValue(":version_id", version_id);
+    }
+
     if (!query.exec()){
         qDebug()<<"SqlError: "<<query.lastError()<<query.executedQuery();
         return false;
@@ -341,9 +321,9 @@ bool Prefix::addPrefix(const QString prefix_name, const QString prefix_path, con
     return true;
 }
 
-bool Prefix::updatePrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString old_prefix_name, const QString arch, const QString mountpoint_windrive, const QString run_string) const{
+bool Prefix::updatePrefix(const QString prefix_name, const QString prefix_path, const QString wine_exec, const QString wine_server, const QString wine_loader, const QString wine_dllpath, const QString cdrom_mount, const QString old_prefix_name, const QString arch, const QString mountpoint_windrive, const QString run_string, const QString version_id) const{
     QSqlQuery query;
-        query.prepare("UPDATE prefix SET wine_dllpath=:wine_dllpath, wine_loader=:wine_loader, wine_server=:wine_server, wine_exec=:wine_exec, cdrom_mount=:cdrom_mount, arch=:arch, name=:prefix_name, mountpoint_windrive=:mountpoint_windrive, path=:prefix_path, run_string=:run_string WHERE name=:old_prefix_name");
+        query.prepare("UPDATE prefix SET wine_dllpath=:wine_dllpath, wine_loader=:wine_loader, wine_server=:wine_server, wine_exec=:wine_exec, cdrom_mount=:cdrom_mount, arch=:arch, name=:prefix_name, mountpoint_windrive=:mountpoint_windrive, path=:prefix_path, run_string=:run_string, version_id=:version_id WHERE name=:old_prefix_name");
 
     query.bindValue(":prefix_name", prefix_name);
     query.bindValue(":old_prefix_name", old_prefix_name);
@@ -402,6 +382,12 @@ bool Prefix::updatePrefix(const QString prefix_name, const QString prefix_path,
         query.bindValue(":run_string", run_string);
     }
 
+    if (version_id.isEmpty()){
+        query.bindValue(":version_id", QVariant(QVariant::String));
+    } else {
+        query.bindValue(":version_id", version_id);
+    }
+
     if (!query.exec()){
         qDebug()<<"SqlError: "<<query.lastError()<<query.executedQuery();
         return false;
