@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey               *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -185,6 +184,7 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     connect(mainExit, SIGNAL(triggered()), this, SLOT(mainExit_Click()));
     connect(menuHelpThisTab, SIGNAL(triggered()), this, SLOT(mainHelpThisTab_Click()));
     connect(mainImportWineIcons, SIGNAL(triggered()), this, SLOT(mainImportWineIcons_Click()));
+    connect(mainVersionManager, SIGNAL(triggered()), this, SLOT(mainVersionManager_Click()));
 
     CoreLib->runAutostart();
 
@@ -204,11 +204,11 @@ MainWindow::MainWindow(int startState, QString run_binary, QWidget * parent, Qt:
     tabAppDBLayout->addWidget(appdbWidget.release());
 #endif
 
-        if (!run_binary.isEmpty())
-            messageReceived(run_binary);
+    if (!run_binary.isEmpty())
+        messageReceived(run_binary);
 
-        if (!trayIcon->isVisible())
-            show();
+    if (!trayIcon->isVisible())
+        show();
 
     return;
 }
@@ -229,7 +229,7 @@ void MainWindow::clearTmp(){
         return;
     }
 
-    if (!CoreLib->checkDirs(QStringList() << "tmp" << "tmp/cache")){
+    if (!CoreLib->checkDirs(QString("%1/.config/%2").arg(QDir::homePath()).arg(APP_SHORT_NAME), QStringList() << "tmp" << "tmp/cache")){
         return;
     }
 
@@ -953,6 +953,12 @@ void MainWindow::mainImportWineIcons_Click(){
     return;
 }
 
+void MainWindow::mainVersionManager_Click(){
+    VersionManager* vers = new VersionManager();
+    vers->exec();
+    delete(vers);
+}
+
 void MainWindow::showNotifycation(const QString header, const QString message){
 #ifdef WITH_DBUS
     QVariantList args;
