@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                           *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -50,25 +49,27 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::WFlags
 
     prefix_id=result.value("id");
 
+    Version ver;
+    ver.id_ = result.value("version_id");
+    if (!ver.load()){
+        ver.clear();
+        ver.name_ = "Default";
+        if (!ver.load()){
+            QMessageBox::critical(this, tr("Error"), tr("Unable to load version by name: %1").arg(ver.name_));
+            return;
+        }
+    }
+    version_name=ver.name_;
+
     txtMountPoint->setText(result.value("mount"));
 
     connect(txtMountPoint, SIGNAL(editingFinished()), this, SLOT(getWineCdromLetter()));
 
     if (prefix_name=="Default"){
-        txtPrefixName->setEnabled(FALSE);
-        txtPrefixPath->setEnabled(FALSE);
+        txtPrefixName->setEnabled(false);
+        txtPrefixPath->setEnabled(false);
 
-        cmdGetPrefixPath->setEnabled(FALSE);
-
-        txtWineLibs->setEnabled(FALSE);
-        txtWineLoaderBin->setEnabled(FALSE);
-        txtWineServerBin->setEnabled(FALSE);
-        txtWineBin->setEnabled(FALSE);
-
-        cmdGetWineLibs->setEnabled(FALSE);
-        cmdGetWineLoaderBin->setEnabled(FALSE);
-        cmdGetWineServerBin->setEnabled(FALSE);
-        cmdGetWineBin->setEnabled(FALSE);
+        cmdGetPrefixPath->setEnabled(false);
 
         txtWineLibs->setText("");
         txtWineLoaderBin->setText("");
@@ -76,15 +77,23 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::WFlags
         txtWineBin->setText("");
     } else {
         cmdGetPrefixPath->installEventFilter(this);
-        cmdGetWineBin->installEventFilter(this);
-        cmdGetWineServerBin->installEventFilter(this);
-        cmdGetWineLoaderBin->installEventFilter(this);
-        cmdGetWineLibs->installEventFilter(this);
 
         txtWineLibs->setText(result.value("libs"));
         txtWineLoaderBin->setText(result.value("loader"));
         txtWineServerBin->setText(result.value("server"));
         txtWineBin->setText(result.value("bin"));
+
+        if (!result.value("libs").isEmpty())
+            cmdClnWineLibs->setEnabled(true);
+
+        if (!result.value("loader").isEmpty())
+            cmdClnWineLoaderBin->setEnabled(true);
+
+        if (!result.value("server").isEmpty())
+            cmdClnWineServerBin->setEnabled(true);
+
+        if (!result.value("bin").isEmpty())
+            cmdClnWineBin->setEnabled(true);
     }
 
     if (!result.value("arch").isEmpty())
@@ -97,14 +106,27 @@ PrefixSettings::PrefixSettings(QString prefix_name, QWidget * parent, Qt::WFlags
 
     txtPrefixName->setText(prefix_name);
     txtPrefixPath->setText(result.value("path"));
-    txtRunString->setText(result.value("run_string"));
 
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
     connect(cmdHelp, SIGNAL(clicked()), this, SLOT(cmdHelp_Click()));
 
+    connect(cmdClnWineBin, SIGNAL(clicked()), this, SLOT(cmdClnWineBin_Click()));
+    connect(cmdClnWineServerBin, SIGNAL(clicked()), this, SLOT(cmdClnWineServerBin_Click()));
+    connect(cmdClnWineLoaderBin, SIGNAL(clicked()), this, SLOT(cmdClnWineLoaderBin_Click()));
+    connect(cmdClnWineLibs, SIGNAL(clicked()), this, SLOT(cmdClnWineLibs_Click()));
+
+    connect(comboVersionList, SIGNAL(currentIndexChanged(const QString)), this, SLOT(comboVersionList_Change(const QString)));
+    connect(comboTemplatesList, SIGNAL(currentIndexChanged(const int)), this, SLOT(comboTemplatesList_Change(const int)));
+    connect(cmdAddVersion, SIGNAL(clicked()), this, SLOT(cmdAddVersion_Click()));
+
+    getVersionsList();
+    connect(txtRunString, SIGNAL(textChanged()), this, SLOT(txtRunString_Changed()));
        // comboArchList->setEnabled(false);
 
+    txtRunString->setText(result.value("run_string"));
+
+
     cmdGetMountPoint->installEventFilter(this);
 
     cmdOk->setFocus(Qt::ActiveWindowFocusReason);
@@ -139,20 +161,34 @@ PrefixSettings::PrefixSettings(QWidget * parent, Qt::WFlags f) : QDialog(parent,
     this->loadThemeIcons();
 
     cmdGetPrefixPath->installEventFilter(this);
-    cmdGetWineBin->installEventFilter(this);
-    cmdGetWineServerBin->installEventFilter(this);
-    cmdGetWineLoaderBin->installEventFilter(this);
-    cmdGetWineLibs->installEventFilter(this);
     cmdGetMountPoint->installEventFilter(this);
 
-    txtRunString->setText(RUN_STRING_TEMPLATE);
+
 
     connect(cmdCancel, SIGNAL(clicked()), this, SLOT(cmdCancel_Click()));
     connect(cmdOk, SIGNAL(clicked()), this, SLOT(cmdOk_Click()));
     connect(cmdHelp, SIGNAL(clicked()), this, SLOT(cmdHelp_Click()));
 
+    connect(cmdClnWineBin, SIGNAL(clicked()), this, SLOT(cmdClnWineBin_Click()));
+    connect(cmdClnWineServerBin, SIGNAL(clicked()), this, SLOT(cmdClnWineServerBin_Click()));
+    connect(cmdClnWineLoaderBin, SIGNAL(clicked()), this, SLOT(cmdClnWineLoaderBin_Click()));
+    connect(cmdClnWineLibs, SIGNAL(clicked()), this, SLOT(cmdClnWineLibs_Click()));
+
     connect(txtPrefixName, SIGNAL(textChanged(QString)), this, SLOT(setDefPath(QString)));
 
+    connect(comboVersionList, SIGNAL(currentIndexChanged(const QString)), this, SLOT(comboVersionList_Change(const QString)));
+    connect(comboTemplatesList, SIGNAL(currentIndexChanged(const int)), this, SLOT(comboTemplatesList_Change(const int)));
+    connect(cmdAddVersion, SIGNAL(clicked()), this, SLOT(cmdAddVersion_Click()));
+
+    getVersionsList();
+    comboVersionList->setCurrentIndex(0);
+    connect(txtRunString, SIGNAL(textChanged()), this, SLOT(txtRunString_Changed()));
+
+    txtRunString->setText(RUN_STRING_TEMPLATE_DEFAULT);
+       // comboArchList->setEnabled(false);
+
+
+
     txtPrefixName->setFocus(Qt::ActiveWindowFocusReason);
     return;
 }
@@ -164,12 +200,14 @@ QString PrefixSettings::getPrefixName(){
 void PrefixSettings::loadThemeIcons(){
     lblLogo->setPixmap(CoreLib->loadPixmap("data/exec.png"));
 
-    cmdGetWineBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineServerBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineLoaderBin->setIcon(CoreLib->loadIcon("data/folder.png"));
-    cmdGetWineLibs->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdClnWineBin->setIcon(CoreLib->loadIcon("data/kill.png"));
+    cmdClnWineServerBin->setIcon(CoreLib->loadIcon("data/kill.png"));
+    cmdClnWineLoaderBin->setIcon(CoreLib->loadIcon("data/kill.png"));
+    cmdClnWineLibs->setIcon(CoreLib->loadIcon("data/kill.png"));
     cmdGetMountPoint->setIcon(CoreLib->loadIcon("data/folder.png"));
     cmdGetPrefixPath->setIcon(CoreLib->loadIcon("data/folder.png"));
+    cmdAddVersion->setIcon(CoreLib->loadIcon("data/add.png"));
+
     return;
 }
 
@@ -197,6 +235,13 @@ void PrefixSettings::cmdOk_Click(){
         txtPrefixPath->setText(path);
     }
 
+    Version ver;
+    ver.name_ = comboVersionList->currentText();
+    if (!ver.load()){
+        QMessageBox::critical(this, tr("Error"), tr("Fail to load version by name: %1").arg(ver.name_));
+        return;
+    }
+
     if (this->addNew){
 
         QDir directory(path);
@@ -213,7 +258,7 @@ void PrefixSettings::cmdOk_Click(){
             }
         }
 
-        if (!db_prefix.addPrefix(txtPrefixName->text(),  txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), comboArchList->currentText(), this->comboWinDrive->currentText(), this->txtRunString->text()))
+        if (!db_prefix.addPrefix(txtPrefixName->text(),  txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), comboArchList->currentText(), this->comboWinDrive->currentText(), this->txtRunString->toPlainText(), ver.id_))
             reject();
 
         CoreLib->createPrefixDBStructure(txtPrefixName->text());
@@ -222,7 +267,7 @@ void PrefixSettings::cmdOk_Click(){
             sys_menu.generateSystemMenu(txtPrefixName->text());
 #endif
     } else {
-        if (!db_prefix.updatePrefix(txtPrefixName->text(), txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), this->prefix_name, comboArchList->currentText(), this->comboWinDrive->currentText(), this->txtRunString->text()))
+        if (!db_prefix.updatePrefix(txtPrefixName->text(), txtPrefixPath->text(), txtWineBin->text(), txtWineServerBin->text(), txtWineLoaderBin->text(), txtWineLibs->text(), txtMountPoint->text(), this->prefix_name, comboArchList->currentText(), this->comboWinDrive->currentText(), this->txtRunString->toPlainText(), ver.id_))
             reject();
 #ifndef _OS_DARWIN_
         if (CoreLib->getSetting("Plugins", "enableMenuDesktop", false, true).toBool()){
@@ -302,7 +347,7 @@ bool PrefixSettings::eventFilter(QObject *obj, QEvent *event){
         }
     }
 
-    return FALSE;
+    return false;
 }
 
 void PrefixSettings::cmdHelp_Click(){
@@ -341,3 +386,123 @@ void PrefixSettings::setDefPath(QString prefix_name){
         this->txtPrefixPath->setText(path);
     }
 }
+
+void PrefixSettings::cmdClnWineBin_Click(){
+    txtWineBin->clear();
+}
+
+void PrefixSettings::cmdClnWineServerBin_Click(){
+    txtWineServerBin->clear();
+}
+
+void PrefixSettings::cmdClnWineLoaderBin_Click(){
+    txtWineLoaderBin->clear();
+}
+
+void PrefixSettings::cmdClnWineLibs_Click(){
+    txtWineLibs->clear();
+}
+
+void PrefixSettings::cmdAddVersion_Click(){
+    VersionManager* vers = new VersionManager();
+    if (!comboVersionList->currentText().isEmpty())
+        vers->setVersionFocus(comboVersionList->currentText());
+    connect(vers, SIGNAL(setVersion(QString)), this, SLOT(setVersion(QString)));
+    vers->exec();
+    disconnect(this, SLOT(setVersion(QString)));
+    delete(vers);
+
+}
+
+void PrefixSettings::getVersionsList(){
+    comboVersionList->clear();
+    Version ver;
+    QList<Version> list = ver.load_all();
+
+    for (int i = 0; i < list.size(); ++i)
+        comboVersionList->addItem(list.at(i).name_);
+
+    comboVersionList->setCurrentIndex(comboVersionList->findText(version_name));
+}
+
+void PrefixSettings::comboVersionList_Change(const QString & text){
+    //version_name = text;
+}
+
+void PrefixSettings::comboTemplatesList_Change(const int id){
+    if (id == 1){
+        txtRunString->setText(RUN_STRING_TEMPLATE_DEFAULT);
+    } else if (id == 2){
+        txtRunString->setText(RUN_STRING_TEMPLATE_X11);
+    } else if (id == 3){
+        txtRunString->setText(RUN_STRING_TEMPLATE_SETARCH);
+    } else if (id == 4){
+        txtRunString->setText(RUN_STRING_TEMPLATE_OPTIRUN);
+    } else if (id == 5){
+        txtRunString->setText(RUN_STRING_TEMPLATE_PRIMUSRUN);
+    }
+}
+
+void PrefixSettings::setVersion(QString version_name){
+    this->version_name = version_name;
+    getVersionsList();
+}
+
+void PrefixSettings::txtRunString_Changed(){
+    QString run_string = txtRunString->toPlainText().replace("\"", "\\\"");
+
+    QString console_bin = CoreLib->getSetting("console", "bin").toString();
+    QString console_args = CoreLib->getSetting("console", "args", false).toString();
+
+    if (console_bin.split("/").last() == "konsole"){
+        console_args.append(" /bin/sh -c ");
+    }
+
+    run_string.replace("%CONSOLE_BIN%", console_bin);
+    run_string.replace("%CONSOLE_ARGS%", QString("%1 \"").arg(console_args));
+
+    Version ver;
+    if (!txtWineBin->text().isEmpty()){
+        ver.wine_exec_ = txtWineBin->text();
+        ver.wine_loader_ = txtWineLoaderBin->text();
+        ver.wine_server_ = txtWineServerBin->text();
+        ver.wine_dllpath32_ = txtWineLibs->text();
+        ver.wine_dllpath64_ = txtWineLibs->text();
+    } else {
+        ver.clear();
+        ver.name_ = comboVersionList->currentText();
+        if (!ver.load()){
+            QMessageBox::critical(this, tr("Error"), tr("Unable to load version by name: %1").arg(ver.name_));
+            return;
+        }
+    }
+
+    QString env;
+    env.append(QString(" WINEPREFIX='%1' ").arg(txtPrefixPath->text()));
+    env.append(QString(" WINESERVER='%1' ").arg(ver.wine_server_));
+    env.append(QString(" WINELOADER='%1' ").arg(ver.wine_loader_));
+    if (comboArchList->currentText()=="win64"){
+        env.append(QString(" WINEDLLPATH='%1' ").arg(ver.wine_dllpath64_));
+    } else if (comboArchList->currentText()=="win32"){
+        env.append(QString(" WINEDLLPATH='%1' ").arg(ver.wine_dllpath32_));
+    }
+    env.append(QString(" WINEARCH='%1' ").arg(comboArchList->currentText()));
+    env.append(QString(" WINEDEBUG='%1' ").arg("-all"));
+    env.append(QString(" WINEDLLOVERRIDES='' "));
+    env.append(QString(" LANG='' "));
+
+    run_string.replace("%ENV_BIN%", CoreLib->getWhichOut("env"));
+    run_string.replace("%ENV_ARGS%", env);
+
+    run_string.replace("%WORK_DIR%", QString("cd \'%1\' &&").arg(QDir::homePath()));
+    run_string.replace("%SET_NICE%", QString("%1 -n 10").arg(CoreLib->getSetting("system", "nice", false).toString()));
+
+    run_string.replace("%WINE_BIN%", ver.wine_exec_);
+
+    run_string.replace("%VIRTUAL_DESKTOP%", " explorer.exe /desktop=winecfg,800x600 ");
+    run_string.replace("%PROGRAM_BIN%", "\'winecfg\'");
+    run_string.replace("%PROGRAM_ARGS%", "-h");
+    run_string.append(" \"");
+
+    lblTemalate->setText(run_string);
+}
