@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                            *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -196,10 +195,11 @@ void PrefixControlWidget::prefixAdd_Click(){
 }
 
 void PrefixControlWidget::updateTableModel(){
-    model->setQuery("SELECT name, arch, path FROM prefix ORDER BY name");
+    model->setQuery("SELECT name, arch, (SELECT name FROM versions WHERE id=version_id), path FROM prefix ORDER BY name");
     model->setHeaderData(0, Qt::Horizontal, tr("Name"));
-    model->setHeaderData(1, Qt::Horizontal, tr("Architecture"));
-    model->setHeaderData(2, Qt::Horizontal, tr("Path"));
+    model->setHeaderData(1, Qt::Horizontal, tr("Arch"));
+    model->setHeaderData(2, Qt::Horizontal, tr("Version"));
+    model->setHeaderData(3, Qt::Horizontal, tr("Path"));
     prefixTable->setModel(model.get());
     prefixTable->resizeColumnsToContents();
     prefixTable->resizeRowsToContents();
