@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                                 *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -88,12 +87,12 @@ int main(int argc, char *argv[])
         qDebug()<<app.arguments().at(i);
         if ((app.arguments().at(1)=="--version") or (app.arguments().at(1)=="-v")){
             Qcout<<QString("%1-helper %2").arg(APP_SHORT_NAME).arg(APP_VERS)<<endl;
-            Qcout<<QString("(Copyright (C) 2008-2009, brezblock core team.")<<endl;
+            Qcout<<QString("Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>")<<endl;
             Qcout<<QString("License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.")<<endl;
             Qcout<<QObject::tr("This is free software: you are free to change and redistribute it.")<<endl;
             Qcout<<QObject::tr("There is NO WARRANTY, to the extent permitted by law.")<<endl;
             CoreLib->getBuildFlags();
-            Qcout<<QObject::tr("Author: %1.").arg("Malakhov Alexey aka John Brezerk")<<endl;
+            Qcout<<QObject::tr("Author: %1.").arg("Alexey S. Malakhov")<<endl;
             return 0;
         } else if (app.arguments().at(i)=="--prefix"){
             i++;
@@ -173,36 +172,5 @@ int main(int argc, char *argv[])
         }
     }
 
-    return wineObject.runSys();
-/*
-    if (app.arguments().count()>1){
-        if ((app.arguments().at(1)=="--version") or (app.arguments().at(1)=="-v")){
-            Qcout<<QString("%1-helper %2").arg(APP_SHORT_NAME).arg(APP_VERS)<<endl;
-            Qcout<<QString("(Copyright (C) 2008-2009, brezblock core team.")<<endl;
-            Qcout<<QString("License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.")<<endl;
-            Qcout<<QObject::tr("This is free software: you are free to change and redistribute it.")<<endl;
-            Qcout<<QObject::tr("There is NO WARRANTY, to the extent permitted by law.")<<endl;
-            CoreLib->getBuildFlags();
-            Qcout<<QObject::tr("Author: %1.").arg("Malakhov Alexey aka John Brezerk")<<endl;
-            return 0;
-        } else if ((app.arguments().at(1)=="--binary") or (app.arguments().at(1)=="-b")) {
-            //startState = 1;
-        } else {
-            Qcout<<QObject::tr("Usage:")<<endl;
-            Qcout<<QString("  %1 -b <unix_path_to_windown_binary>").arg(APP_SHORT_NAME)<<endl;
-            Qcout<<QObject::tr("  %1 [KEY]...").arg(APP_SHORT_NAME)<<endl;
-            Qcout<<QObject::tr("GUI utility for wine applications and prefixes management.")<<endl<<endl;
-            Qcout<<QObject::tr("KEYs list:")<<endl;
-            Qcout<<qSetFieldWidth(25)<<left<<"  -h,  --help"<<QObject::tr("display this help and exit")<<qSetFieldWidth(0)<<endl;
-            Qcout<<qSetFieldWidth(25)<<left<<"  -v,  --version"<<QObject::tr("output version information and exit")<<qSetFieldWidth(0)<<endl;
-            Qcout<<qSetFieldWidth(25)<<left<<"  -b,  --binary"<<QObject::tr("Open Q4Wine run dialog for windows binary")<<qSetFieldWidth(0)<<endl;
-            Qcout<<qSetFieldWidth(25)<<left<<"  -m,  --minimize"<<QObject::tr("minimize %1 main window on startup").arg(APP_SHORT_NAME)<<qSetFieldWidth(0)<<endl;
-            Qcout<<endl;
-            Qcout<<QObject::tr("Report %1 bugs to %2").arg(APP_SHORT_NAME).arg(APP_BUG_EMAIL)<<endl;
-            Qcout<<QObject::tr("%1 homepage: <%2>").arg(APP_SHORT_NAME).arg(APP_WEBSITE)<<endl;
-            Qcout<<QObject::tr("General help using GNU software: <http://www.gnu.org/gethelp/>")<<endl;
-            return 0;
-        }
-    }
-*/
+    return wineObject.run();
 }
