@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010, 2011 by Malakhov Alexey                           *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -1077,12 +1076,6 @@ QStringList corelib::getCdromDevices(void) const{
             QString u_path;
 
             if (path.length()<=0){
-                /* if (this->_GUI_MODE){
-                    qDebug()<<"[EE] No binary passed sSsssssssssssSSSSSSSSSSSs ============"<<path;
-                    QMessageBox::warning(0, QObject::tr("Error"), QObject::tr("No binary passed to function"));
-                } else {
-                    qDebug()<<"[EE] No binary passed";
-                } */
                 return true;
             }
 
